@@ -1,39 +1,58 @@
-#' Probability Density Functions for Probabilistic 
+#' Probability Density Functions for Probabilistic
 #' Uncertainty Analysis
 #' 
 #' Define a distribution for PSA parameters.
 #' 
-#' These functions are not exported, but only used in 
-#' [define_psa()]. To specify a user-made function
-#' use `define_distribution`.
+#' These functions are not exported, but only used
+#' in [define_psa()]. To specify a user-made 
+#' function use [define_distribution()].
 #' 
-#' `define_distribution` takes as argument a function
-#' with a single argument, `x`, corresponding to a
-#' vector of quantiles. It returns the distribution values
-#' for the given quantiles. See examples
+#' [use_distribution()] uses gaussian kernel 
+#' smoothing with a bandwith parameter calculated 
+#' by [stats::density()]. Values for unobserved
+#' quantiles are calculated by linear
+#' interpolation.
+#' 
+#' [define_distribution()] takes as argument a 
+#' function with a single argument, `x`, 
+#' corresponding to a vector of quantiles. It 
+#' returns the distribution values for the given 
+#' quantiles. See examples.
 #' 
 #' @name distributions
 #' @param mean Distribution mean.
 #' @param sd Distribution standard deviation.
 #' @param ... Dirichlet distribution parameters.
 #' @param prob Proportion.
-#' @param size Size of sample used to estimate proportion.
+#' @param size Size of sample used to estimate 
+#'   proportion.
 #' @param meanlog Mean on the log scale.
 #' @param sdlog SD on the log scale.
 #' @param mu Mean on the logit scale.
 #' @param sigma SD on the logit scale.
 #' @param shape1 for beta distribution
 #' @param shape2 for beta distribution
-#' @param lower lower bound of triangular distribution.
-#' @param upper upper bound of triangular distribution.
+#' @param lower lower bound of triangular 
+#'   distribution.
+#' @param upper upper bound of triangular 
+#'   distribution.
 #' @param peak peak of triangular distribution.
 #' @param x A distribution function, see details.
+#' @param distribution A numeric vector of 
+#'   observations defining a distribution, usually
+#'   the output from an MCMC fit.
+#' @param smooth Use gaussian kernel smoothing?
 #'   
 #' @examples 
 #' define_distribution(
 #'   function(x) stats::qexp(p = x, rate = 0.5)
 #' )
 #' 
+#' # a mixture of 2 gaussians
+#' x <- c(rnorm(100), rnorm(100, 6))
+#' plot(density(x))
+#' 
+#' use_distribution(x)
 normal <- function(mean, sd) {
   list(r_normal(mean, sd))
 }
@@ -79,18 +98,18 @@ r_binomial <- function(prob, size) {
 #' @rdname distributions
 multinomial <- function(...) {
   list_param <- list(...)
-  total = sum(unlist(list_param))
+  
   structure(
-    lapply(list_param, function(x) r_multinomial(x, total)),
-    class = c("list", "multinom_param")
+    lapply(list_param, function(x) r_multinomial(x)),
+    class = "multinom_param"
   )
 }
 multinom <- function(...) {
   warning("'multinom()' is deprecated, use 'multinomial()' instead.")
   multinomial(...)
 }
-r_multinomial <- function(n, total) {
-  function(x) stats::qbeta(x, n, total - n)
+r_multinomial <- function(n) {
+  function(x) stats::qgamma(x, shape = n, scale = 1)
 }
 
 #' @rdname distributions
@@ -165,3 +184,27 @@ triangle <- function(lower, upper, peak = (lower + upper)/2) {
 r_triangle <- function(lower, upper, peak) {
   function(x) triangle::qtriangle(p = x, a = lower, b = upper, c = peak)
 }
+
+#' @rdname distributions
+#' @export
+use_distribution <- function(distribution, smooth = TRUE) {
+  distribution <- sort(distribution)
+  
+  define_distribution(
+    function(x) {
+      if (smooth) {
+        noise <- stats::rnorm(
+          n = length(x),
+          mean = 0,
+          sd = stats::density(distribution)$bw
+        )
+      } else {
+        noise <- 0
+      }
+      
+      stats::approxfun(
+        x = seq(0, 1, length = length(distribution)),
+        y = distribution)(x) + noise
+    }
+  )
+}
