@@ -48,7 +48,7 @@ res2 <- run_model(
 rsp <- define_psa(
   age_init ~ normal(60, 10),
   cost_init ~ normal(1000, 100),
-  p_trans ~ prop(.7, 100),
+  p_trans ~ binomial(.7, 100),
   correlation = matrix(c(
     1,  .4, 0,
     .4, 1,  0,
